==> ruby-puppet-0.24.4p1.tgz: lib/ruby/site_ruby/1.8/puppet/network/http/mongrel.rb <==
require 'mongrel' if Puppet.features.mongrel?

require 'puppet/network/http/mongrel/rest'
require 'puppet/network/http/mongrel/xmlrpc'

class Puppet::Network::HTTP::Mongrel
    def initialize(args = {})
        @listening = false
    end
    
    def listen(args = {})
        raise ArgumentError, ":handlers must be specified." if !args[:handlers] or args[:handlers].empty?
        raise ArgumentError, ":protocols must be specified." if !args[:protocols] or args[:protocols].empty?
        raise ArgumentError, ":address must be specified." unless args[:address]
        raise ArgumentError, ":port must be specified." unless args[:port]
        raise "Mongrel server is already listening" if listening?
        
        @protocols = args[:protocols]
        @handlers = args[:handlers]
        @server = Mongrel::HttpServer.new(args[:address], args[:port])

        setup_handlers

        @server.run
        @listening = true
    end
    
    def unlisten
        raise "Mongrel server is not listening" unless listening?
        @server.graceful_shutdown
        @listening = false
    end
    
    def listening?
        @listening
    end
    
  private
  
    def setup_handlers
        @protocols.each do |protocol|
            @handlers.each do |handler|
                class_for_protocol(protocol).new(:server => @server, :handler => handler)
            end
        end
    end
  
    # TODO/FIXME: need a spec which forces delegation to the real class
    def class_for_protocol(protocol)
        return Puppet::Network::HTTP::MongrelREST if protocol.to_sym == :rest
        return Puppet::Network::HTTP::MongrelXMLRPC if protocol.to_sym == :xmlrpc
        raise ArgumentError, "Unknown protocol [#{protocol}]."
    end
end

==> ruby-puppet-0.25.5.tgz: lib/ruby/site_ruby/1.8/puppet/network/http/mongrel.rb <==
require 'mongrel' if Puppet.features.mongrel?

require 'puppet/network/http/mongrel/rest'

class Puppet::Network::HTTP::Mongrel
    def initialize(args = {})
        @listening = false
    end

    def listen(args = {})
        raise ArgumentError, ":protocols must be specified." if !args[:protocols] or args[:protocols].empty?
        raise ArgumentError, ":address must be specified." unless args[:address]
        raise ArgumentError, ":port must be specified." unless args[:port]
        raise "Mongrel server is already listening" if listening?

        @protocols = args[:protocols]
        @xmlrpc_handlers = args[:xmlrpc_handlers]
        @server = Mongrel::HttpServer.new(args[:address], args[:port])
        setup_handlers

        @listening = true
        @server.run
    end

    def unlisten
        raise "Mongrel server is not listening" unless listening?
        @server.stop
        @server = nil
        @listening = false
    end

    def listening?
        @listening
    end

  private

    def setup_handlers
        # Register our REST support at /
        klass = class_for_protocol(:rest)
        @server.register('/', klass.new(:server => @server))

        if @protocols.include?(:xmlrpc) and ! @xmlrpc_handlers.empty?
            setup_xmlrpc_handlers
        end
    end

    # Use our existing code to provide the xmlrpc backward compatibility.
    def setup_xmlrpc_handlers
        @server.register('/RPC2', Puppet::Network::HTTPServer::Mongrel.new(@xmlrpc_handlers))
    end

    def class_for_protocol(protocol)
        return Puppet::Network::HTTP::MongrelREST if protocol.to_sym == :rest
        raise ArgumentError, "Unknown protocol [#{protocol}]."
    end
end
